IOSseChannel class
IO-backed implementation of SseChannel that communicates with an SSE
endpoint using package:http.
- Inheritance
-
- Object
- StreamChannelMixin
- IOSseChannel
- Implemented types
Constructors
- IOSseChannel(StreamChannel channel)
- IOSseChannel.connect(Uri url)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sink
→ StreamSink<
String?> -
The sink for sending values to the other endpoint.
no setteroverride
-
stream
→ Stream<
Event> -
The single-subscription stream that emits values from the other endpoint.
no setteroverride
Methods
-
cast<
S> () → StreamChannel< S> -
Returns a copy of this with the generic type coerced to
S.inherited -
changeSink(
StreamSink change(StreamSink)) → StreamChannel -
Returns a copy of this with sink replaced by
change's return value.inherited -
changeStream(
Stream change(Stream)) → StreamChannel -
Returns a copy of this with stream replaced by
change's return value.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipe(
StreamChannel other) → void -
Connects this to
other, so that any values emitted by either are sent directly to the other.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
transform<
S> (StreamChannelTransformer< S, dynamic> transformer) → StreamChannel<S> -
Transforms this using
transformer.inherited -
transformSink(
StreamSinkTransformer transformer) → StreamChannel -
Transforms only the sink component of this using
transformer.inherited -
transformStream(
StreamTransformer transformer) → StreamChannel -
Transforms only the stream component of this using
transformer.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited